@@ -5,19 +5,23 @@ from robo_appian.components.DropdownUtils import DropdownUtils
 from robo_appian.components.InputUtils import InputUtils
 from robo_appian.components.LabelUtils import LabelUtils
 from robo_appian.components.LinkUtils import LinkUtils
+from robo_appian.components.SearchDropdownUtils import SearchDropdownUtils
 from robo_appian.components.TableUtils import TableUtils
 from robo_appian.components.TabUtils import TabUtils
+from robo_appian.utils.BrowserUtils import BrowserUtils
 
 __version__ = "0.0.2"
 
 __all__ = [
     "ButtonUtils",
-    "ComponentUtils", 
+    "ComponentUtils",
     "DateUtils",
     "DropdownUtils",
     "InputUtils",
     "LabelUtils",
     "LinkUtils",
+    "SearchDropdownUtils",
     "TableUtils",
-    "TabUtils"
+    "TabUtils",
+    "BrowserUtils",
 ]
