@@ -1,5 +1,6 @@
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import WebDriverWait
+from selenium.webdriver.common.by import By
 from robo_appian.utils.ComponentUtils import ComponentUtils
 
 
@@ -24,12 +25,12 @@ class LabelUtils:
         Example:
             component = LabelUtils._findByLabelText(wait, "Submit")
         """
-        xpath = f".//*[normalize-space(.)='{label}']"
+        xpath = f'//*[normalize-space(translate(., "\u00a0", " "))="{label}"]'
         try:
             # component = wait.until(EC.visibility_of_element_located((By.XPATH, xpath)))
-            component = ComponentUtils.findVisibleComponentByXpath(wait, xpath)
+            component = ComponentUtils.waitForComponentToBeVisibleByXpath(wait, xpath)
         except Exception as e:
-            raise RuntimeError(f"Label with text '{label}' not found.") from e
+            raise Exception(f"Label with text '{label}' not found.") from e
 
         return component
 
@@ -48,9 +49,19 @@ class LabelUtils:
         component.click()
 
     @staticmethod
-    def checkLabelExists(wait: WebDriverWait, label: str):
+    def isLabelExists(wait: WebDriverWait, label: str):
         try:
             LabelUtils.__findByLabelText(wait, label)
         except Exception:
             return False
         return True
+
+    @staticmethod
+    def isLabelExistsAfterLoad(wait: WebDriverWait, label: str):
+        try:
+            xpath = f'.//*[normalize-space(translate(., "\u00a0", " "))="{label}"]'
+            wait.until(EC.presence_of_element_located((By.XPATH, xpath)))
+            wait.until(EC.visibility_of_element_located((By.XPATH, xpath)))
+        except Exception:
+            return False
+        return True
