@@ -34,7 +34,9 @@ class ComponentUtils:
         return yesterday_formatted
 
     @staticmethod
-    def findChildComponentByXpath(wait: WebDriverWait, component: WebElement, xpath: str):
+    def findChildComponentByXpath(
+        wait: WebDriverWait, component: WebElement, xpath: str
+    ):
         """Finds a child component using the given XPath within a parent component.
 
         :param wait: WebDriverWait instance to wait for elements
@@ -54,28 +56,11 @@ class ComponentUtils:
         try:
             component = wait.until(lambda comp: component.find_element(By.XPATH, xpath))
         except Exception:
-            raise Exception(f"Child component with XPath '{xpath}' not found within the given parent component.")
+            raise Exception(
+                f"Child component with XPath '{xpath}' not found within the given parent component."
+            )
         return component
 
-    @staticmethod
-    def findComponentUsingXpathAndClick(wait: WebDriverWait, xpath: str):
-        """Finds a component using the given XPath and clicks it.
-
-        :param wait: WebDriverWait instance to wait for elements
-        :param xpath: XPath string to locate the component
-        :return: None
-        Example usage:
-        from selenium.webdriver.support.ui import WebDriverWait
-        from selenium import webdriver
-
-        driver = webdriver.Chrome()
-        wait = WebDriverWait(driver, 10)
-        xpath = "//button[@id='submit']"
-        ComponentUtils.findComponentUsingXpathAndClick(wait, xpath)
-        """
-        component = ComponentUtils.findVisibleComponentByXpath(wait, xpath)
-        component.click()
-
     @staticmethod
     def findComponentById(wait: WebDriverWait, id: str):
         try:
@@ -85,27 +70,38 @@ class ComponentUtils:
         return component
 
     @staticmethod
-    def findVisibleComponentByXpath(wait: WebDriverWait, xpath: str):
-        """
-        Finds a component using the given XPath in the current WebDriver instance.
-
-            :param wait: WebDriverWait instance to wait for elements
-            :param xpath: XPath string to locate the component
-            :return: WebElement if found, raises NoSuchElementException otherwise
-
-        Example usage:
-            component = ComponentUtils.findVisibleComponentByXpath(wait, "//button[@id='submit']")
-            component.click()
-        """
-        component = wait.until(EC.visibility_of_element_located((By.XPATH, xpath)))
+    def waitForComponentToBeVisibleByXpath(wait: WebDriverWait, xpath: str):
+        try:
+            component = wait.until(EC.visibility_of_element_located((By.XPATH, xpath)))
+        except Exception:
+            raise Exception(f"Component with XPath '{xpath}' not visible.")
         return component
 
+    # @staticmethod
+    # def waitForComponentToBeVisibleByXpath(wait: WebDriverWait, xpath: str):
+    #     """
+    #     Finds a component using the given XPath in the current WebDriver instance.
+
+    #         :param wait: WebDriverWait instance to wait for elements
+    #         :param xpath: XPath string to locate the component
+    #         :return: WebElement if found, raises NoSuchElementException otherwise
+
+    #     Example usage:
+    #         component = ComponentUtils.waitForComponentToBeVisibleByXpath(wait, "//button[@id='submit']")
+    #         component.click()
+    #     """
+    #     try:
+    #         component = wait.until(EC.visibility_of_element_located((By.XPATH, xpath)))
+    #     except Exception:
+    #         raise Exception(f"Component with XPath '{xpath}' not visible.")
+    #     return component
+
     @staticmethod
     def checkComponentExistsByXpath(wait: WebDriverWait, xpath: str):
         """Checks if a component with the given XPath exists in the current WebDriver instance."""
         status = False
         try:
-            ComponentUtils.findVisibleComponentByXpath(wait, xpath)
+            ComponentUtils.waitForComponentToBeVisibleByXpath(wait, xpath)
             status = True
         except NoSuchElementException:
             pass
@@ -147,7 +143,9 @@ class ComponentUtils:
         length = 0
 
         try:
-            component = wait.until(EC.presence_of_all_elements_located((By.XPATH, xpath)))
+            component = wait.until(
+                EC.presence_of_all_elements_located((By.XPATH, xpath))
+            )
             length = len(component)
         except NoSuchElementException:
             pass
@@ -200,3 +198,81 @@ class ComponentUtils:
             return valid_components
 
         raise Exception(f"No valid components found for XPath: {xpath}")
+
+    @staticmethod
+    def findComponentByXPath(wait: WebDriverWait, xpath: str):
+        # component = wait.until(EC.presence_of_element_located((By.XPATH, xpath)))
+        component = wait._driver.find_element(By.XPATH, xpath)
+        return component
+
+    @staticmethod
+    def findComponentUsingXpathAndClick(wait: WebDriverWait, xpath: str):
+        """Finds a component using the given XPath and clicks it.
+
+        :param wait: WebDriverWait instance to wait for elements
+        :param xpath: XPath string to locate the component
+        :return: None
+        Example usage:
+        from selenium.webdriver.support.ui import WebDriverWait
+        from selenium import webdriver
+
+        driver = webdriver.Chrome()
+        wait = WebDriverWait(driver, 10)
+        xpath = "//button[@id='submit']"
+        ComponentUtils.findComponentUsingXpathAndClick(wait, xpath)
+        """
+
+        component = ComponentUtils.waitForComponentToBeVisibleByXpath(wait, xpath)
+        ComponentUtils.click(wait, component)
+
+    @staticmethod
+    def click(wait: WebDriverWait, component: WebElement):
+        """
+        Clicks the given component after waiting for it to be clickable.
+
+            :param wait: WebDriverWait instance to wait for elements
+            :param component: WebElement representing the component to click
+            :return: None
+        Example usage:
+            ComponentUtils.click(wait, component)
+        """
+        wait.until(EC.element_to_be_clickable(component))
+        component.click()
+
+    @staticmethod
+    def waitForComponentToBeInVisible(wait: WebDriverWait, component: WebElement):
+        try:
+            wait.until(EC.staleness_of(component))
+        except Exception:
+            raise Exception(
+                "Component did not become invisible (stale) within the timeout period."
+            )
+
+    @staticmethod
+    def isComponentPresentByXpath(wait: WebDriverWait, xpath: str):
+        status = False
+        try:
+            wait.until(EC.presence_of_element_located((By.XPATH, xpath)))
+            status = True
+        except NoSuchElementException:
+            pass
+
+        return status
+
+    @staticmethod
+    def waitForElementToBeVisibleById(wait: WebDriverWait, id: str):
+        return wait.until(EC.visibility_of_element_located((By.ID, id)))
+
+    @staticmethod
+    def waitForElementNotToBeVisibleById(wait: WebDriverWait, id: str):
+        return wait.until(EC.invisibility_of_element_located((By.ID, id)))
+
+    @staticmethod
+    def waitForElementToBeVisibleByText(wait: WebDriverWait, text: str):
+        xpath = f'//*[normalize-space(translate(., "\u00a0", " "))="{text}" and not(*[normalize-space(translate(., "\u00a0", " "))="{text}"]) and not(ancestor-or-self::*[contains(@class, "---hidden")])]'
+        return wait.until(EC.visibility_of_element_located((By.XPATH, xpath)))
+
+    @staticmethod
+    def waitForElementNotToBeVisibleByText(wait: WebDriverWait, text: str):
+        xpath = f'//*[normalize-space(translate(., "\u00a0", " "))="{text}" and not(*[normalize-space(translate(., "\u00a0", " "))="{text}"]) and not(ancestor-or-self::*[contains(@class, "---hidden")])]'
+        return wait.until(EC.invisibility_of_element_located((By.XPATH, xpath)))
